@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -378,6 +378,7 @@ struct mod_chxj_config {
 #define CONVRULE_QSCONV_OFF_BIT       (0x00000200)
 #define CONVRULE_JRCONV_OFF_BIT       (0x00000400)
 #define CONVRULE_NOCACHE_ON_BIT       (0x00000800)
+#define CONVRULE_EMOJI_ONLY_BIT       (0x00001000)
 
 #define CONVRULE_ENGINE_ON_CMD        "EngineOn"
 #define CONVRULE_ENGINE_OFF_CMD       "EngineOff"
@@ -391,11 +392,10 @@ struct mod_chxj_config {
 #define CONVRULE_Z2H_NUM_OFF_CMD      "Z2hNumOff"
 #define CONVRULE_Z2H_ALL_ON_CMD       "Z2hAllOn"
 #define CONVRULE_Z2H_ALL_OFF_CMD      "Z2hAllOff"
-#define CONVRULE_Z2H_ALL_ON_CMD       "Z2hAllOn"
-#define CONVRULE_Z2H_ALL_OFF_CMD      "Z2hAllOff"
 #define CONVRULE_QSCONV_OFF_CMD       "QSConvOff"
 #define CONVRULE_JRCONV_OFF_CMD       "JRConvOff"
 #define CONVRULE_NOCACHE_ON_CMD       "NoCacheOn"
+#define CONVRULE_EMOJI_ONLY_CMD       "EmojiOnly"
 
 
 #define CONVRULE_FLAG_NOTMATCH        (0x00000001)
