@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -219,12 +219,16 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
     }
   }
   else {
-    *ilen = 0;
-    return;
+    /* unknown 1byte charactor */
+    **obuf = '?';
+    *obuf += 1;
+    *olen -= 1;
+    *ibuf += 1;
+    DBG(r, "passed 1byte.");
   }
   if (ibuf && *ibuf) {
     *ilen = strlen(*ibuf);
-    DBG(r, "new len = [%d].", *ilen);
+    DBG(r, "new len = [%" APR_SIZE_T_FMT "].", (apr_size_t)*ilen);
   }
 }
 
@@ -338,6 +342,8 @@ chxj_encoding_parameter(request_rec *r, const char *value)
   char *val;
   char *vstat;
   char *param;
+  char *anchor_pos;
+  char *anchor;
 
   int   use_amp_flag;
   
@@ -345,10 +351,22 @@ chxj_encoding_parameter(request_rec *r, const char *value)
 
   src = apr_pstrdup(r->pool, value);
 
+  anchor_pos = strchr(src, '#');
+  if (anchor_pos) {
+    anchor_pos++;
+    anchor = apr_pstrdup(r->pool, anchor_pos);
+    anchor_pos--;
+    *anchor_pos = 0;
+  }
+
   spos = strchr(src, '?');
   if (!spos) {
     DBG(r, "end   chxj_encoding_parameter()");
-    return src;
+    if (anchor_pos) {
+      return apr_pstrcat(r->pool, src, "#", anchor, NULL);
+    } else {
+      return src;
+    }
   }
   *spos++ = 0;
 
@@ -420,7 +438,11 @@ chxj_encoding_parameter(request_rec *r, const char *value)
   }
   DBG(r, "end   chxj_encoding_parameter()");
 
-  return apr_pstrcat(r->pool, src_sv, "?", param, NULL);
+  if (anchor_pos) {
+    return apr_pstrcat(r->pool, src_sv, "?", param, "#", anchor, NULL);
+  } else {
+    return apr_pstrcat(r->pool, src_sv, "?", param, NULL);
+  }
 }
 /*
  * vim:ts=2 et
