@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -590,6 +590,67 @@ s_jhtml_search_emoji(jhtml_t *jhtml, char *txt, char **rslt)
 }
 
 
+char *
+chxj_jhtml_emoji_only_converter(request_rec *r, device_table *spec, const char *src, apr_size_t len)
+{
+  apr_size_t ii;
+  Doc __doc;
+  Doc *doc;
+  jhtml_t __jhtml;
+  jhtml_t *jhtml;
+  char one_byte[2];
+  char two_byte[3];
+  apr_pool_t *pool;
+
+  jhtml = &__jhtml;
+  doc   = &__doc;
+
+  DBG(r, "REQ[%X] start chxj_jhtml_emoji_eonly_converter()", (apr_size_t)(unsigned int)r);
+  memset(doc,   0, sizeof(Doc));
+  memset(jhtml, 0, sizeof(jhtml_t));
+
+  doc->r      = r;
+  jhtml->doc  = doc;
+  jhtml->spec = spec;
+  jhtml->out  = qs_alloc_zero_byte_string(r->pool);
+  jhtml->conf = chxj_get_module_config(r->per_dir_config, &chxj_module);
+  jhtml->doc->parse_mode = PARSE_MODE_CHTML;
+
+  apr_pool_create(&pool, r->pool);
+
+  chxj_buffered_write_init(pool, &doc->buf);
+
+  for (ii=0; ii<len; ii++) {
+    char *out;
+    int   rtn;
+
+    rtn = s_jhtml_search_emoji(jhtml, (char *)&src[ii], &out);
+    if (rtn) {
+      W_V(out);
+      ii+=(rtn - 1);
+      continue;
+    }
+
+    if (is_sjis_kanji(src[ii])) {
+      two_byte[0] = src[ii+0];
+      two_byte[1] = src[ii+1];
+      two_byte[2] = 0;
+      W_V(two_byte);
+      ii++;
+    }
+    else {
+      one_byte[0] = src[ii+0];
+      one_byte[1] = 0;
+      W_V(one_byte);
+    }
+  }
+  jhtml->out = chxj_buffered_write_flush(jhtml->out, &doc->buf);
+
+  DBG(r, "REQ[%X] end chxj_jhtml_emoji_eonly_converter()", (apr_size_t)(unsigned int)r);
+  return jhtml->out;
+}
+
+
 /**
  * It is a handler who processes the HTML tag.
  *
