@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -468,8 +468,10 @@ chxj_chxjif_is_mine(device_table *spec, Doc *doc, Node *tag)
     if ((*name == 'l' || *name == 'L') && strcasecmp(name, "lang") == 0) {
 
       DBG(r, "lang found [%s] spec [%d]", value, spec->html_spec_type);
-
-      if (STRCASEEQ('x','X',"xhtml",value)) {
+      if (STRCASEEQ('a','A',"all",value)) {
+        return 1;
+      }
+      else if (STRCASEEQ('x','X',"xhtml",value)) {
         if (spec->html_spec_type == CHXJ_SPEC_XHtml_Mobile_1_0) {
           /* Yes , it is mine */
           return 1;
@@ -624,6 +626,9 @@ chxj_form_action_to_hidden_tag(
   for (;;) {
     char *pair = apr_strtok(s, "&", &pstat);
     if (! pair) break;
+    if (strncasecmp(pair, "amp;", 4) == 0) {
+      pair += 4;
+    }
     s = NULL;
     char *key = apr_strtok(pair, "=",  &pstat2);
     char *val = "";
@@ -648,14 +653,28 @@ chxj_form_action_to_hidden_tag(
       else {
         if (! post || strcasecmp(key, "_chxj_cc") == 0 || strcasecmp(key, "_chxj_nc") == 0) {
           if (softbank) {
-            tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", chxj_jreserved_to_safe_tag(r, key, entryp), chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+            tmp = apr_psprintf(pool, 
+                               "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", 
+                               chxj_jreserved_to_safe_tag(r, 
+                                                          chxj_url_decode(pool, key), 
+                                                          entryp), 
+                               chxj_url_decode(pool, val), 
+                               (xmlFlag == 1) ? " /" : "");
           }
           else {
-            tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+            tmp = apr_psprintf(pool, 
+                               "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", 
+                               chxj_url_decode(pool, key), 
+                               chxj_url_decode(pool, val), 
+                               (xmlFlag == 1) ? " /" : "");
           }
         }
         else {
-          tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"_chxj_qs_%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+          tmp = apr_psprintf(pool, 
+                             "<input type=\"hidden\" name=\"_chxj_qs_%s\" value=\"%s\"%s>", 
+                             chxj_url_decode(pool, key), 
+                             chxj_url_decode(pool, val), 
+                             (xmlFlag == 1) ? " /" : "");
         }
         if (result) {
           result = apr_pstrcat(pool, result, tmp, NULL);
